@@ -47,7 +47,7 @@ class CurrencyRates(Common):
 
     def get_rates(self, base_cur, date_obj=None):
         date_str = self._get_date_string(date_obj)
-        payload = {'base': base_cur}
+        payload = {'base': base_cur, 'rtype': 'fpy'}
         source_url = self._source_url() + date_str
         response = requests.get(source_url, params=payload)
         if response.status_code == 200:
@@ -61,7 +61,7 @@ class CurrencyRates(Common):
                 return Decimal(1)
             return 1.
         date_str = self._get_date_string(date_obj)
-        payload = {'base': base_cur, 'symbols': dest_cur}
+        payload = {'base': base_cur, 'symbols': dest_cur, 'rtype': 'fpy'}
         source_url = self._source_url() + date_str
         response = requests.get(source_url, params=payload)
         if response.status_code == 200:
@@ -84,7 +84,7 @@ class CurrencyRates(Common):
             return float(amount)
 
         date_str = self._get_date_string(date_obj)
-        payload = {'base': base_cur, 'symbols': dest_cur}
+        payload = {'base': base_cur, 'symbols': dest_cur, 'rtype': 'fpy'}
         source_url = self._source_url() + date_str
         response = requests.get(source_url, params=payload)
         if response.status_code == 200:
